@@ -54,6 +54,7 @@ class LogcatMonitor:
     _logs = []
     _key_dict = KEYWORDS_DICT
     _pool = ThreadPool(1)
+    _save_logcat = True
 
     def __init__(self, serial_number=None, parent_folder=None, key_dict=None, rows=INTERCEPTED_MAX_ROWS):
         if key_dict is not None:
@@ -72,12 +73,13 @@ class LogcatMonitor:
         # Statistics
         self._statistics = Statistics()
 
-    def start_monitor(self):
+    def start_monitor(self, save_logcat=True):
         """
             Start logcat monitor
         :return:
         """
         self._stop_logcat = False
+        self._save_logcat = save_logcat
         print("Start monitor _logcat")
         self._pool.add_task(self._filter_keyword)
 
@@ -175,7 +177,8 @@ class LogcatMonitor:
                         except Exception as ex:
                             print(ex)
                             line_str = str(ex)
-                        log_file.write(line_str)
+                        if self._save_logcat:
+                            log_file.write(line_str)
                         if not intercept:
                             # Read data normally
                             for key in keys:
